==> puppet-strings_2.1.0.orig.tar.gz: puppet-strings-2.1.0/misc/ANNOUNCEMENT_TEMPLATE.md <==
Send out announcements for major new feature releases, and high-impact bugfixes to <puppet-announce@googlegroups.com>, <puppet-dev@googlegroups.com>, <puppet-users@googlegroups.com>, <voxpupuli@groups.io>, and the puppet internal mailing lists <dev@puppet.com> and <tech-discuss@puppet.com>.

Before sending, do check that all links are still valid. Feel free to adjust the text to match better with the circumstances of the release, or add other news that are relevant at the time. If you make changes, consider committing them here, for the benefit of future-you.

The github rendering of the markdown seems to copy&paste acceptably into Google Inbox.

The [CHANGELOG](https://github.com/puppetlabs/puppet-strings/blob/master/CHANGELOG.md) is a good starting point for finding enhancements and bug-fixes.

---

Subject: [ANN] Puppet Strings vX.Y.Z Release

Hi all,

We're pleased to announce that version X.Y.Z of the Puppet Strings is being released today.

Puppet Strings provides a simple way to extract source documentation into useful docs. It is provided as a Ruby gem to be referenced within modules. See the [README](https://github.com/puppetlabs/puppet-strings#installing-puppet-strings) for documentation on how to install and use it.


The new release of Puppet Strings provides the following enhancements:

* A
* B
* C

The new release also contains the following notable bugfixes:

* D
* E
* F

See the [CHANGELOG](https://github.com/puppetlabs/puppet-strings/blob/master/CHANGELOG.md) for a full list of changes

We encourage all module developers to review puppet-strings and use it when creating modules.

Please let us know of your experiences with Puppet Strings, either here, on [Slack](https://slack.puppet.com/) (#forge-modules), or on the [github repo](https://github.com/puppetlabs/puppet-strings).


Thanks,
YOUR NAME

==> puppet-strings_2.9.0.orig.tar.gz: puppet-strings-2.9.0/misc/ANNOUNCEMENT_TEMPLATE.md <==
Send out announcements for major new feature releases, and high-impact bugfixes to <puppet-announce@googlegroups.com>, <puppet-dev@googlegroups.com>, <puppet-users@googlegroups.com>, <voxpupuli@groups.io>, and the puppet internal mailing lists <dev@puppet.com> and <tech-discuss@puppet.com>.

Before sending, do check that all links are still valid. Feel free to adjust the text to match better with the circumstances of the release, or add other news that are relevant at the time. If you make changes, consider committing them here, for the benefit of future-you.

The github rendering of the markdown seems to copy&paste acceptably into Google Inbox.

The [CHANGELOG](https://github.com/puppetlabs/puppet-strings/blob/main/CHANGELOG.md) is a good starting point for finding enhancements and bug-fixes.

---

Subject: [ANN] Puppet Strings vX.Y.Z Release

Hi all,

We're pleased to announce that version X.Y.Z of the Puppet Strings is being released today.

Puppet Strings provides a simple way to extract source documentation into useful docs. It is provided as a Ruby gem to be referenced within modules. See the [README](https://github.com/puppetlabs/puppet-strings#installing-puppet-strings) for documentation on how to install and use it.


The new release of Puppet Strings provides the following enhancements:

* A
* B
* C

The new release also contains the following notable bugfixes:

* D
* E
* F

See the [CHANGELOG](https://github.com/puppetlabs/puppet-strings/blob/main/CHANGELOG.md) for a full list of changes

We encourage all module developers to review puppet-strings and use it when creating modules.

Please let us know of your experiences with Puppet Strings, either here, on [Slack](https://slack.puppet.com/) (#forge-modules), or on the [github repo](https://github.com/puppetlabs/puppet-strings).


Thanks,
YOUR NAME
